changeset 51181:9de1323b5882

(iconify-or-deiconify-frame): Move to frame.el. Turn on mouse-wheel support by default.
author Stefan Monnier <monnier@iro.umontreal.ca>
date Sat, 24 May 2003 16:13:06 +0000
parents 8444fb4d51cf
children 3dd4104b45b6
files lisp/term/x-win.el
diffstat 1 files changed, 11 insertions(+), 15 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/term/x-win.el	Sat May 24 16:11:17 2003 +0000
+++ b/lisp/term/x-win.el	Sat May 24 16:13:06 2003 +0000
@@ -243,8 +243,8 @@
 	x-invocation-args (cdr x-invocation-args)))
 
 (defvar emacs-save-session-functions nil
-  "Functions to run when a save-session event occurs.
-The functions does not get any argument.
+  "Special hook run when a save-session event occurs.
+The functions do not get any argument.
 Functions can return non-nil to inform the session manager that the
 window system shutdown should be aborted.
 
@@ -1159,13 +1159,6 @@
 
 ;;;; Function keys
 
-(defun iconify-or-deiconify-frame ()
-  "Iconify the selected frame, or deiconify if it's currently an icon."
-  (interactive)
-  (if (eq (cdr (assq 'visibility (frame-parameters))) t)
-      (iconify-frame)
-    (make-frame-visible)))
-
 (substitute-key-definition 'suspend-emacs 'iconify-or-deiconify-frame
 			   global-map)
 
@@ -2367,11 +2360,14 @@
 ;; Don't show the frame name; that's redundant with X.
 (setq-default mode-line-frame-identification "  ")
 
-;;; Motif direct handling of f10 wasn't working right,
-;;; So temporarily we've turned it off in lwlib-Xm.c
-;;; and turned the Emacs f10 back on.
-;;; ;; Motif normally handles f10 itself, so don't try to handle it a second time.
-;;; (if (featurep 'motif)
-;;;     (global-set-key [f10] 'ignore))
+;; Motif direct handling of f10 wasn't working right,
+;; So temporarily we've turned it off in lwlib-Xm.c
+;; and turned the Emacs f10 back on.
+;; ;; Motif normally handles f10 itself, so don't try to handle it a second time.
+;; (if (featurep 'motif)
+;;     (global-set-key [f10] 'ignore))
+
+;; Turn on support for mouse wheels.
+(mouse-wheel-mode 1)
 
 ;;; x-win.el ends here